Welcome to simple_openid_connect's documentation!
=================================================

`simple_openid_connect` is a **simple** and **opinionated** OpenID-Connect relying party and resource server implementation.
This means it can be used by an app to authenticate users as well as validate access tokens passed to it.

Quick Links
-----------

- `PyPi package <https://pypi.org/project/simple_openid_connect/>`_
- `Documentation <https://simple-openid-connect.readthedocs.io/en/latest/>`_
- `GitHub Repository <https://github.com/fsinfuhh/py_simple_openid_connect>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   django-integration
   drf-integration
   api
